==> zio-aws-macie2_3-5.17.124.3-sources.jar: zio/aws/macie2/model/GetCustomDataIdentifierRequest.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.macie2.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class GetCustomDataIdentifierRequest(id: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.GetCustomDataIdentifierRequest = {
    import GetCustomDataIdentifierRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.GetCustomDataIdentifierRequest
      .builder()
      .id(__string.unwrap(id): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.macie2.model.GetCustomDataIdentifierRequest.ReadOnly =
    zio.aws.macie2.model.GetCustomDataIdentifierRequest.wrap(buildAwsValue())
}
object GetCustomDataIdentifierRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.GetCustomDataIdentifierRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.GetCustomDataIdentifierRequest =
      zio.aws.macie2.model.GetCustomDataIdentifierRequest(id)
    def id: __string
    def getId: ZIO[Any, Nothing, __string] = ZIO.succeed(id)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.GetCustomDataIdentifierRequest
  ) extends zio.aws.macie2.model.GetCustomDataIdentifierRequest.ReadOnly {
    override val id: __string =
      zio.aws.macie2.model.primitives.__string(impl.id())
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.GetCustomDataIdentifierRequest
  ): zio.aws.macie2.model.GetCustomDataIdentifierRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-macie2_3-5.19.7.2-sources.jar: zio/aws/macie2/model/GetCustomDataIdentifierRequest.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.macie2.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class GetCustomDataIdentifierRequest(id: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.GetCustomDataIdentifierRequest = {
    import GetCustomDataIdentifierRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.GetCustomDataIdentifierRequest
      .builder()
      .id(id: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.macie2.model.GetCustomDataIdentifierRequest.ReadOnly =
    zio.aws.macie2.model.GetCustomDataIdentifierRequest.wrap(buildAwsValue())
}
object GetCustomDataIdentifierRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.GetCustomDataIdentifierRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.GetCustomDataIdentifierRequest =
      zio.aws.macie2.model.GetCustomDataIdentifierRequest(id)
    def id: __string
    def getId: ZIO[Any, Nothing, __string] = ZIO.succeed(id)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.GetCustomDataIdentifierRequest
  ) extends zio.aws.macie2.model.GetCustomDataIdentifierRequest.ReadOnly {
    override val id: __string = impl.id(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.GetCustomDataIdentifierRequest
  ): zio.aws.macie2.model.GetCustomDataIdentifierRequest.ReadOnly = new Wrapper(
    impl
  )
}
